pub struct SsoProviderStore<'a> { /* private fields */ }Expand description
Adapter-backed store for SSO provider records.
Implementations
Sourceimpl<'a> SsoProviderStore<'a>
impl<'a> SsoProviderStore<'a>
Sourcepub fn new(adapter: &'a dyn DbAdapter) -> Self
pub fn new(adapter: &'a dyn DbAdapter) -> Self
Create a provider store over an RustAuth adapter.
Sourcepub fn new_with_model(adapter: &'a dyn DbAdapter, model_name: &'a str) -> Self
pub fn new_with_model(adapter: &'a dyn DbAdapter, model_name: &'a str) -> Self
Create a provider store using a custom logical model name.
Sourcepub fn new_with_options(
adapter: &'a dyn DbAdapter,
options: &'a SsoOptions,
) -> Self
pub fn new_with_options( adapter: &'a dyn DbAdapter, options: &'a SsoOptions, ) -> Self
Create a provider store from plugin options.
Sourcepub fn new_with_model_and_domain_verification(
adapter: &'a dyn DbAdapter,
model_name: &'a str,
include_domain_verified: bool,
) -> Self
pub fn new_with_model_and_domain_verification( adapter: &'a dyn DbAdapter, model_name: &'a str, include_domain_verified: bool, ) -> Self
Create a provider store with explicit model and domain verification field support.
Sourcepub async fn list(&self) -> Result<Vec<SsoProviderRecord>, RustAuthError>
pub async fn list(&self) -> Result<Vec<SsoProviderRecord>, RustAuthError>
List all SSO providers.
Sourcepub async fn list_by_user(
&self,
user_id: &str,
) -> Result<Vec<SsoProviderRecord>, RustAuthError>
pub async fn list_by_user( &self, user_id: &str, ) -> Result<Vec<SsoProviderRecord>, RustAuthError>
List SSO providers owned by a user.
Sourcepub async fn find_by_provider_id(
&self,
provider_id: &str,
) -> Result<Option<SsoProviderRecord>, RustAuthError>
pub async fn find_by_provider_id( &self, provider_id: &str, ) -> Result<Option<SsoProviderRecord>, RustAuthError>
Find an SSO provider by stable provider id.
Sourcepub async fn find_by_organization_id(
&self,
organization_id: &str,
) -> Result<Option<SsoProviderRecord>, RustAuthError>
pub async fn find_by_organization_id( &self, organization_id: &str, ) -> Result<Option<SsoProviderRecord>, RustAuthError>
Find the first SSO provider assigned to an organization.
Sourcepub async fn create(
&self,
input: CreateSsoProviderInput,
) -> Result<SsoProviderRecord, RustAuthError>
pub async fn create( &self, input: CreateSsoProviderInput, ) -> Result<SsoProviderRecord, RustAuthError>
Create an SSO provider record.
Sourcepub async fn update_domain_verified(
&self,
provider_id: &str,
verified: bool,
) -> Result<Option<SsoProviderRecord>, RustAuthError>
pub async fn update_domain_verified( &self, provider_id: &str, verified: bool, ) -> Result<Option<SsoProviderRecord>, RustAuthError>
Update a provider domain verification flag.
Sourcepub async fn update(
&self,
provider_id: &str,
input: UpdateSsoProviderInput,
) -> Result<Option<SsoProviderRecord>, RustAuthError>
pub async fn update( &self, provider_id: &str, input: UpdateSsoProviderInput, ) -> Result<Option<SsoProviderRecord>, RustAuthError>
Partially update an SSO provider record.